# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/publisherd/v1/publisherd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/publisherd/v1/publisherd.proto',
  package='github.com.metaprov.modelaapi.services.publisherd.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/publisherd/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/publisherd/v1/publisherd.proto\x12\x34github.com.metaprov.modelaapi.services.publisherd.v1\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xff\x02\n\x16PublishNotebookRequest\x12\x14\n\x0cnotebookName\x18\x01 \x01(\t\x12\x19\n\x11notebookNamespace\x18\x02 \x01(\t\x12\\\n\x0cnotebookSpec\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookSpec\x12\x17\n\x0fNotebookContent\x18\x04 \x01(\t\x12\x12\n\nDockerfile\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\",\n\x17PublishNotebookResponse\x12\x11\n\tImageName\x18\x01 \x01(\t\"\xdf\t\n\x10\x42\x61keModelRequest\x12V\n\x0b\x64\x61taproduct\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12\x64\n\x12\x64\x61taproductversion\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05model\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x06 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x11\n\timagename\x18\x08 \x01(\t\x12\x1c\n\x14imagenameWithVersion\x18\t \x01(\t\x12\x0c\n\x04push\x18\n \x01(\x08\x12T\n\x06\x62ucket\x18\x0b \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\tcloudConn\x18\x0c \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12l\n\x0b\x63loudSecret\x18\r \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.CloudSecretEntry\x12[\n\x10\x64ockerConnection\x18\x0e \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12~\n\x14\x64ockerRegistrySecret\x18\x0f \x03(\x0b\x32`.github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.DockerRegistrySecretEntry\x12\x0e\n\x06kaniko\x18\x13 \x01(\x08\x1a\x32\n\x10\x43loudSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a;\n\x19\x44ockerRegistrySecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"&\n\x11\x42\x61keModelResponse\x12\x11\n\tImageName\x18\x01 \x01(\t\"\xe2\x06\n\x0fTarModelRequest\x12V\n\x0b\x64\x61taproduct\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12\x64\n\x12\x64\x61taproductversion\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05model\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x06 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\tcloudConn\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12k\n\x0b\x63loudSecret\x18\t \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.CloudSecretEntry\x1a\x32\n\x10\x43loudSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\"\n\x10TarModelResponse\x12\x0e\n\x06tarUri\x18\x01 \x01(\t\"\x11\n\x0fShutdownRequest\"\x12\n\x10ShutdownResponse2\xa0\x05\n\x11PublisherdService\x12\x9d\x01\n\nPublishTar\x12\x45.github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest\x1a\x46.github.com.metaprov.modelaapi.services.publisherd.v1.TarModelResponse\"\x00\x12\x99\x01\n\x04\x42\x61ke\x12\x46.github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest\x1aG.github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelResponse\"\x00\x12\xb0\x01\n\x0fPublishNotebook\x12L.github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest\x1aM.github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookResponse\"\x00\x12\x9b\x01\n\x08Shutdown\x12\x45.github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownRequest\x1a\x46.github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownResponse\"\x00\x42\x36Z4github.com/metaprov/modelaapi/services/publisherd/v1b\x06proto3'
  ,
  dependencies=[github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_PUBLISHNOTEBOOKREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=726,
)

_PUBLISHNOTEBOOKREQUEST = _descriptor.Descriptor(
  name='PublishNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='notebookName', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.notebookName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebookNamespace', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.notebookNamespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notebookSpec', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.notebookSpec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='NotebookContent', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.NotebookContent', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Dockerfile', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.Dockerfile', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.provider', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PUBLISHNOTEBOOKREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=726,
)


_PUBLISHNOTEBOOKRESPONSE = _descriptor.Descriptor(
  name='PublishNotebookResponse',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ImageName', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookResponse.ImageName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=728,
  serialized_end=772,
)


_BAKEMODELREQUEST_CLOUDSECRETENTRY = _descriptor.Descriptor(
  name='CloudSecretEntry',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.CloudSecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.CloudSecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.CloudSecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1911,
  serialized_end=1961,
)

_BAKEMODELREQUEST_DOCKERREGISTRYSECRETENTRY = _descriptor.Descriptor(
  name='DockerRegistrySecretEntry',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.DockerRegistrySecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.DockerRegistrySecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.DockerRegistrySecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1963,
  serialized_end=2022,
)

_BAKEMODELREQUEST = _descriptor.Descriptor(
  name='BakeModelRequest',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataproduct', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.dataproduct', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataproductversion', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.dataproductversion', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.model', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.study', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.datasource', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.dataset', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.provider', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imagename', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.imagename', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imagenameWithVersion', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.imagenameWithVersion', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='push', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.push', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.bucket', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloudConn', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.cloudConn', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloudSecret', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.cloudSecret', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dockerConnection', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.dockerConnection', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dockerRegistrySecret', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.dockerRegistrySecret', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kaniko', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.kaniko', index=15,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BAKEMODELREQUEST_CLOUDSECRETENTRY, _BAKEMODELREQUEST_DOCKERREGISTRYSECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=2022,
)


_BAKEMODELRESPONSE = _descriptor.Descriptor(
  name='BakeModelResponse',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ImageName', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelResponse.ImageName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2062,
)


_TARMODELREQUEST_CLOUDSECRETENTRY = _descriptor.Descriptor(
  name='CloudSecretEntry',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.CloudSecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.CloudSecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.CloudSecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1911,
  serialized_end=1961,
)

_TARMODELREQUEST = _descriptor.Descriptor(
  name='TarModelRequest',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataproduct', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.dataproduct', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataproductversion', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.dataproductversion', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.model', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.study', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.datasource', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.dataset', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.bucket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloudConn', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.cloudConn', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cloudSecret', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.cloudSecret', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TARMODELREQUEST_CLOUDSECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2065,
  serialized_end=2931,
)


_TARMODELRESPONSE = _descriptor.Descriptor(
  name='TarModelResponse',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tarUri', full_name='github.com.metaprov.modelaapi.services.publisherd.v1.TarModelResponse.tarUri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2933,
  serialized_end=2967,
)


_SHUTDOWNREQUEST = _descriptor.Descriptor(
  name='ShutdownRequest',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2969,
  serialized_end=2986,
)


_SHUTDOWNRESPONSE = _descriptor.Descriptor(
  name='ShutdownResponse',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2988,
  serialized_end=3006,
)

_PUBLISHNOTEBOOKREQUEST_SECRETENTRY.containing_type = _PUBLISHNOTEBOOKREQUEST
_PUBLISHNOTEBOOKREQUEST.fields_by_name['notebookSpec'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKSPEC
_PUBLISHNOTEBOOKREQUEST.fields_by_name['secret'].message_type = _PUBLISHNOTEBOOKREQUEST_SECRETENTRY
_BAKEMODELREQUEST_CLOUDSECRETENTRY.containing_type = _BAKEMODELREQUEST
_BAKEMODELREQUEST_DOCKERREGISTRYSECRETENTRY.containing_type = _BAKEMODELREQUEST
_BAKEMODELREQUEST.fields_by_name['dataproduct'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_BAKEMODELREQUEST.fields_by_name['dataproductversion'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_BAKEMODELREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_BAKEMODELREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_BAKEMODELREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_BAKEMODELREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_BAKEMODELREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_BAKEMODELREQUEST.fields_by_name['cloudConn'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_BAKEMODELREQUEST.fields_by_name['cloudSecret'].message_type = _BAKEMODELREQUEST_CLOUDSECRETENTRY
_BAKEMODELREQUEST.fields_by_name['dockerConnection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_BAKEMODELREQUEST.fields_by_name['dockerRegistrySecret'].message_type = _BAKEMODELREQUEST_DOCKERREGISTRYSECRETENTRY
_TARMODELREQUEST_CLOUDSECRETENTRY.containing_type = _TARMODELREQUEST
_TARMODELREQUEST.fields_by_name['dataproduct'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_TARMODELREQUEST.fields_by_name['dataproductversion'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_TARMODELREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_TARMODELREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_TARMODELREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_TARMODELREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_TARMODELREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_TARMODELREQUEST.fields_by_name['cloudConn'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_TARMODELREQUEST.fields_by_name['cloudSecret'].message_type = _TARMODELREQUEST_CLOUDSECRETENTRY
DESCRIPTOR.message_types_by_name['PublishNotebookRequest'] = _PUBLISHNOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['PublishNotebookResponse'] = _PUBLISHNOTEBOOKRESPONSE
DESCRIPTOR.message_types_by_name['BakeModelRequest'] = _BAKEMODELREQUEST
DESCRIPTOR.message_types_by_name['BakeModelResponse'] = _BAKEMODELRESPONSE
DESCRIPTOR.message_types_by_name['TarModelRequest'] = _TARMODELREQUEST
DESCRIPTOR.message_types_by_name['TarModelResponse'] = _TARMODELRESPONSE
DESCRIPTOR.message_types_by_name['ShutdownRequest'] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['ShutdownResponse'] = _SHUTDOWNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PublishNotebookRequest = _reflection.GeneratedProtocolMessageType('PublishNotebookRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHNOTEBOOKREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _PUBLISHNOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest)
  })
_sym_db.RegisterMessage(PublishNotebookRequest)
_sym_db.RegisterMessage(PublishNotebookRequest.SecretEntry)

PublishNotebookResponse = _reflection.GeneratedProtocolMessageType('PublishNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHNOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookResponse)
  })
_sym_db.RegisterMessage(PublishNotebookResponse)

BakeModelRequest = _reflection.GeneratedProtocolMessageType('BakeModelRequest', (_message.Message,), {

  'CloudSecretEntry' : _reflection.GeneratedProtocolMessageType('CloudSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _BAKEMODELREQUEST_CLOUDSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.CloudSecretEntry)
    })
  ,

  'DockerRegistrySecretEntry' : _reflection.GeneratedProtocolMessageType('DockerRegistrySecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _BAKEMODELREQUEST_DOCKERREGISTRYSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest.DockerRegistrySecretEntry)
    })
  ,
  'DESCRIPTOR' : _BAKEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelRequest)
  })
_sym_db.RegisterMessage(BakeModelRequest)
_sym_db.RegisterMessage(BakeModelRequest.CloudSecretEntry)
_sym_db.RegisterMessage(BakeModelRequest.DockerRegistrySecretEntry)

BakeModelResponse = _reflection.GeneratedProtocolMessageType('BakeModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _BAKEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.BakeModelResponse)
  })
_sym_db.RegisterMessage(BakeModelResponse)

TarModelRequest = _reflection.GeneratedProtocolMessageType('TarModelRequest', (_message.Message,), {

  'CloudSecretEntry' : _reflection.GeneratedProtocolMessageType('CloudSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _TARMODELREQUEST_CLOUDSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest.CloudSecretEntry)
    })
  ,
  'DESCRIPTOR' : _TARMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.TarModelRequest)
  })
_sym_db.RegisterMessage(TarModelRequest)
_sym_db.RegisterMessage(TarModelRequest.CloudSecretEntry)

TarModelResponse = _reflection.GeneratedProtocolMessageType('TarModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _TARMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.TarModelResponse)
  })
_sym_db.RegisterMessage(TarModelResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)


DESCRIPTOR._options = None
_PUBLISHNOTEBOOKREQUEST_SECRETENTRY._options = None
_BAKEMODELREQUEST_CLOUDSECRETENTRY._options = None
_BAKEMODELREQUEST_DOCKERREGISTRYSECRETENTRY._options = None
_TARMODELREQUEST_CLOUDSECRETENTRY._options = None

_PUBLISHERDSERVICE = _descriptor.ServiceDescriptor(
  name='PublisherdService',
  full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublisherdService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3009,
  serialized_end=3681,
  methods=[
  _descriptor.MethodDescriptor(
    name='PublishTar',
    full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublisherdService.PublishTar',
    index=0,
    containing_service=None,
    input_type=_TARMODELREQUEST,
    output_type=_TARMODELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Bake',
    full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublisherdService.Bake',
    index=1,
    containing_service=None,
    input_type=_BAKEMODELREQUEST,
    output_type=_BAKEMODELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PublishNotebook',
    full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublisherdService.PublishNotebook',
    index=2,
    containing_service=None,
    input_type=_PUBLISHNOTEBOOKREQUEST,
    output_type=_PUBLISHNOTEBOOKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Shutdown',
    full_name='github.com.metaprov.modelaapi.services.publisherd.v1.PublisherdService.Shutdown',
    index=3,
    containing_service=None,
    input_type=_SHUTDOWNREQUEST,
    output_type=_SHUTDOWNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PUBLISHERDSERVICE)

DESCRIPTOR.services_by_name['PublisherdService'] = _PUBLISHERDSERVICE

# @@protoc_insertion_point(module_scope)
